@@ -129,6 +129,14 @@ public class BuildManager implements ICoreConstants, IManager, ILifecycleListene
 
 	private ILock lock;
 
+	/**
+	 * {@code true} if we can exit inner build loop cycle early after
+	 * rebuildRequested is set by one build config and before following build
+	 * configs are executed. Default is {@code false} to keep legacy behavior.
+	 */
+	private static final boolean EARLY_EXIT_FROM_INNER_BUILD_LOOP_ALLOWED = System
+			.getProperty("org.eclipse.core.resources.allowEarlyInnerBuildLoopExit") != null; //$NON-NLS-1$
+
 	//used for the build cycle looping mechanism
 	private boolean rebuildRequested = false;
 
@@ -256,6 +264,11 @@ public class BuildManager implements ICoreConstants, IManager, ILifecycleListene
 		try {
 			for (int i = 0; i < commands.length; i++) {
 				checkCanceled(trigger, monitor);
+				if (EARLY_EXIT_FROM_INNER_BUILD_LOOP_ALLOWED && rebuildRequested) {
+					// Don't build following configs if one of the predecessors
+					// requested rebuild anyway, just start from scratch
+					break;
+				}
 				BuildCommand command = (BuildCommand) commands[i];
 				IProgressMonitor sub = Policy.subMonitorFor(monitor, 1);
 				IncrementalProjectBuilder builder = getBuilder(buildConfiguration, command, i, status, context);
@@ -402,7 +415,6 @@ public class BuildManager implements ICoreConstants, IManager, ILifecycleListene
 	/**
 	 * Runs all builders on all the given project configs, in the order that
 	 * they are given.
-	 * @param buildJobGroup
 	 * @return A status indicating if the build succeeded or failed
 	 */
 	public IStatus buildParallel(Digraph<IBuildConfiguration> configs, IBuildConfiguration[] requestedConfigs, int trigger, JobGroup buildJobGroup, IProgressMonitor monitor) {
@@ -448,7 +460,7 @@ public class BuildManager implements ICoreConstants, IManager, ILifecycleListene
 			} catch (CoreException ex) {
 				status.add(new Status(IStatus.ERROR, ResourcesPlugin.PI_RESOURCES, ex.getMessage(), ex));
 			}
-		}, buildJobGroup);
+		}, config -> getRule(config, trigger, null, Collections.emptyMap()), buildJobGroup);
 		graphProcessor.processGraphWithParallelJobs();
 		try {
 			Job.getJobManager().join(graphProcessor, monitor);
