@@ -13,8 +13,6 @@
  *******************************************************************************/
 package org.eclipse.core.tests.filesystem;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
 import org.eclipse.core.filesystem.EFS;
 import org.eclipse.core.filesystem.IFileSystem;
 
@@ -23,18 +21,6 @@ import org.eclipse.core.filesystem.IFileSystem;
  * @see EFS
  */
 public class EFSTest extends FileSystemTest {
-	public static Test suite() {
-		return new TestSuite(EFSTest.class);
-	}
-
-	public EFSTest() {
-		super("");
-	}
-
-	public EFSTest(String name) {
-		super(name);
-	}
-
 	public void testGetLocalFileSystem() {
 		IFileSystem system = EFS.getLocalFileSystem();
 		assertNotNull("1.0", system);
