@@ -13,23 +13,10 @@
  *******************************************************************************/
 package org.eclipse.core.tests.internal.events;
 
-import junit.framework.*;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
-public class AllTests extends TestCase {
-
-	public AllTests() {
-		this(null);
-	}
-
-	public AllTests(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		TestSuite suite = new TestSuite(AllTests.class.getName());
-
-		suite.addTest(BuildProjectFromMultipleJobsTest.suite());
-
-		return suite;
-	}
+@RunWith(Suite.class)
+@Suite.SuiteClasses({ BuildProjectFromMultipleJobsTest.class })
+public class AllTests {
 }
