@@ -14,9 +14,7 @@
  *******************************************************************************/
 package org.eclipse.core.tests.internal.properties;
 
-import java.util.Vector;
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import java.util.ArrayList;
 import org.eclipse.core.internal.properties.IPropertyManager;
 import org.eclipse.core.internal.properties.PropertyManager2;
 import org.eclipse.core.internal.resources.Workspace;
@@ -45,21 +43,6 @@ public class PropertyManagerTest extends LocalStoreTest {
 		}
 	}
 
-	public static Test suite() {
-		//			TestSuite suite = new TestSuite();
-		//			suite.addTest(new PropertyManagerTest("testDeleteProperties"));
-		//			return suite;
-		return new TestSuite(PropertyManagerTest.class);
-	}
-
-	public PropertyManagerTest() {
-		super(null);
-	}
-
-	public PropertyManagerTest(String name) {
-		super(name);
-	}
-
 	private void createProperties(IFile target, QualifiedName[] names, String[] values) {
 		for (int i = 0; i < names.length; i++) {
 			names[i] = new QualifiedName("org.eclipse.core.tests", "prop" + i);
@@ -484,10 +467,10 @@ public class PropertyManagerTest extends LocalStoreTest {
 		String propValue1 = "this is the property value1";
 		String propValue2 = "this is the property value2";
 		String propValue3 = "this is the property value3";
-		Vector<StoredProperty> props = new Vector<>(3);
-		props.addElement(new StoredProperty(propName1, propValue1));
-		props.addElement(new StoredProperty(propName2, propValue2));
-		props.addElement(new StoredProperty(propName3, propValue3));
+		ArrayList<StoredProperty> props = new ArrayList<>(3);
+		props.add(new StoredProperty(propName1, propValue1));
+		props.add(new StoredProperty(propName2, propValue2));
+		props.add(new StoredProperty(propName3, propValue3));
 
 		// set the properties individually and retrieve them
 		for (StoredProperty prop : props) {
