@@ -14,9 +14,7 @@
  *******************************************************************************/
 package org.eclipse.core.tests.resources.usecase;
 
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.List;
+import java.util.*;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.runtime.CoreException;
@@ -29,13 +27,6 @@ import org.eclipse.core.runtime.Path;
  * Only snapshots are taken. No full saves.
  */
 public class Snapshot2Test extends SnapshotTest {
-	public Snapshot2Test() {
-		super();
-	}
-
-	public Snapshot2Test(String name) {
-		super(name);
-	}
 
 	protected static String[] defineHierarchy1() {
 		List<String> result = new ArrayList<>();
